@@ -6,7 +6,7 @@
 
 #pragma once
 
-#include <mailtransport_export.h>
+#include "mailtransport_export.h"
 
 #include <QSslSocket>
 
