@@ -10,11 +10,12 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MAILTRANSPORT_TRANSPORTCONFIGWIDGET_H
-#define MAILTRANSPORT_TRANSPORTCONFIGWIDGET_H
+#pragma once
 
+#include "mailtransport_export.h"
 #include <QWidget>
-#include <mailtransport_export.h>
+
+#include <memory>
 
 class KConfigDialogManager;
 
@@ -77,7 +78,7 @@ public Q_SLOTS:
     virtual void apply();
 
 protected:
-    TransportConfigWidgetPrivate *const d_ptr;
+    std::unique_ptr<TransportConfigWidgetPrivate> const d_ptr;
     TransportConfigWidget(TransportConfigWidgetPrivate &dd, Transport *transport, QWidget *parent);
 
 private:
@@ -87,4 +88,3 @@ private:
 };
 } // namespace MailTransport
 
-#endif // MAILTRANSPORT_TRANSPORTCONFIGWIDGET_H
